# Android 2 Linux Notifications Server
**Android 2 Linux Notifications** (**A2LN**) is a way to display your Android phone notifications on your Linux computer. This repository contains the server part of A2LN.

More information can be found at [patri9ck.dev/a2ln](https://patri9ck.dev/a2ln/).

## License
A2LN is licensed under the [GNU General Public License Version 3 or later](COPYING).
